AdsSdk class

Constructors

AdsSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

apkUniqueKey String
getter/setter pair
serverUrl String
getter/setter pair

Static Methods

getApiKey(String username) Future<void>
initialize(String serverurl, String apkUniqueKey) Future<void>
makeApiKey(BuildContext context, String username) Future<void>
showAdsBanner(BuildContext context, double aspectRatio) Widget
showAdsBottomBanner(BuildContext context, double aspectRatio) Widget
showBannerAd(BuildContext context, double width, double height, Alignment alignment) Widget
showModalAtStart(BuildContext context) → void
showModalTimer(BuildContext context) → void
storeData(String apkUniqueKey, String urlServer) Future<void>